@@ -17,6 +17,7 @@ import dpath
 import json
 import logging
 import os
+import six
 import subprocess
 import sys
 import yaml
@@ -38,13 +39,13 @@ def write_input_file(file_path, content):
     prepare_dir(os.path.dirname(file_path))
     with os.fdopen(os.open(
             file_path, os.O_CREAT | os.O_WRONLY, 0o600), 'w') as f:
-        f.write(content.encode('utf-8'))
+        f.write(content)
 
 
 def build_response(deploy_stdout, deploy_stderr, deploy_status_code):
     return {
-        'deploy_stdout': deploy_stdout,
-        'deploy_stderr': deploy_stderr,
+        'deploy_stdout': deploy_stdout.decode('utf-8', 'replace'),
+        'deploy_stderr': deploy_stderr.decode('utf-8', 'replace'),
         'deploy_status_code': deploy_status_code,
     }
 
@@ -87,7 +88,7 @@ def main(argv=sys.argv):
     for value in dpath.util.values(config, '*/env_file'):
         if isinstance(value, list):
             compose_env_files.extend(value)
-        elif isinstance(value, basestring):
+        elif isinstance(value, six.string_types):
             compose_env_files.extend([value])
 
     input_env_files = {}
